import {
    AllColorKeyType,
    ColorUtils,
} from '@nuskin/foundation-theme';

import { Themed } from '../common.types';
import {
    AccordionVariant,
    AccordionVariantType,
} from './enums';

const { getGenomeColor } = ColorUtils;
const compKeys = ['contentBg', 'contentText', 'headBg', 'headText'];
type CompKeys = (typeof compKeys)[number];
type VariantColors = Record<CompKeys, AllColorKeyType>;

export const colorMap: Record<AccordionVariantType, VariantColors> = {
    basic: {
        contentBg: 'N20',
        contentText: 'N90',
        headBg: 'N10',
        headText: 'N90',
    },
    compact: {
        contentBg: 'N10',
        contentText: 'N90',
        headBg: 'N10',
        headText: 'N90',
    },
    gray: {
        contentBg: 'N40',
        contentText: 'N80',
        headBg: 'N30',
        headText: 'N70',
    },
    stripe: {
        contentBg: 'N30',
        contentText: 'N70',
        headBg: 'N10',
        headText: 'N80',
    },
};

type GetAccordionColor = {
    variant: AccordionVariantType;
    invert: boolean;
    keys: CompKeys[];
} & Themed;
export const getAccordionColor = ({ theme, variant, invert, keys }: GetAccordionColor): Record<CompKeys, string> => {
    const result: Record<string, string> = {};
    if (!Object.values(AccordionVariant).includes(variant)) {
        throw new Error(`Invalid variant ${variant}`);
    }
    for (const colorKey of keys) {
        const appColorKey = colorMap[variant][colorKey];
        const colorValue = getGenomeColor(theme, appColorKey, invert ? 'dark' : 'light');
        result[colorKey] = colorValue;
    }
    return result;
};
