import { AccordionItem, AccordionVariant, NsCollapse } from '@/common/index';
import { render, screen } from '@/test-utils/index';
import React from 'react';

import { createAccordionItem3_1 } from '../stories/data';

describe('NsCollapse', () => {
    it('1. renders children when isOpen is true', () => {
        const { getByText } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Basic}
                content={
                    <>
                        <div>Child 1</div>
                        <div>Child 2</div>
                    </>
                }
                type="jsx"
                isChild={false}
                invert={false}
                level={0}
            />
        );
        expect(getByText('Child 1')).toBeInTheDocument();
        expect(getByText('Child 2')).toBeInTheDocument();
    });
    it('2. renders children when isOpen is true and isChild is true', () => {
        const content = 'renders children when isOpen is true and isChild is true';
        const { getByText } = render(
            <NsCollapse
                isOpen
                type="text"
                variant={AccordionVariant.Basic}
                content={content}
                isChild={true}
                invert={false}
                level={0}
            />
        );
        expect(getByText(content)).toBeInTheDocument();
    });
    it('3. renders children when isOpen is true and variant is compact and content is of type accordion', () => {
        const accItem = createAccordionItem3_1();
        const content = accItem.content as AccordionItem[];
        const { getByText } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Compact}
                content={content}
                type={accItem.type}
                isChild={true}
                invert={false}
                level={0}
            />
        );
        expect(getByText(content[0].title as string)).toBeInTheDocument();
        expect(getByText(content[1].title as string)).toBeInTheDocument();
    });

    it('4. does not render children when isOpen is false', () => {
        const content = '<h2>Lorem ipsum dolor sit amet.</h2>';
        render(
            <NsCollapse
                isOpen={false}
                variant={AccordionVariant.Basic}
                type="html"
                content={content}
                isChild={false}
                invert={true}
                level={0}
            />
        );
        expect(screen.queryByText(content)).toBeNull();
    });
    it('5. renders html children when isOpen is true', () => {
        const content = '<h2>Lorem ipsum dolor sit amet.</h2>';
        render(
            <NsCollapse
                isOpen={true}
                variant={AccordionVariant.Compact}
                type="html"
                content={content}
                isChild={false}
                invert={true}
                level={0}
            />
        );
        expect(screen.queryByText(content)).toBeDefined();
    });

    it('6. renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const { container } = render(
            <NsCollapse
                type="jsx"
                isOpen
                variant={AccordionVariant.Gray}
                content={
                    <>
                        <div>Child 1</div>
                        <div>Child 2</div>
                    </>
                }
                additionalProps={{ className: additionalClassName }}
                isChild={false}
                invert={false}
                level={7}
            />
        );
        expect(container.querySelector('section')).toHaveClass(`ns-collapse ${additionalClassName}`);
    });
    it('7. skipping allowMultipleExpanded in child data', () => {
        const { content, type } = createAccordionItem3_1();
        const additionalClassName = 'custom-class';
        const { container } = render(
            <NsCollapse
                type={type}
                isOpen
                variant={AccordionVariant.Gray}
                content={content}
                additionalProps={{ className: additionalClassName }}
                isChild={false}
                invert={true}
                level={7}
            />
        );
        expect(container.querySelector('section')).toHaveClass(`ns-collapse ${additionalClassName}`);
    });
});
