import React, {
    ReactElement,
    useEffect,
    useState,
} from 'react';

import useWindowSize from '../hooks/useWindowSize';
import { NsIcon } from '../icon';
import { NsTypography } from '../typography';
import Header, {
    colorMap,
    iconMap,
} from './Header';
import {
    Alert,
    AlertBody,
    AlertCloseButton,
    AlertContainer,
    AlertContent,
    AlertFoot,
    AlertHead,
    AlertIcon,
} from './NsAlert.styled';
import type {
    AlertType,
    ContextType,
    NsAlertProps,
} from './types.d';

export default function NsAlert({
    context = 'info',
    title = 'Information',
    threshold = 600,
    type = 'banner',
    visible = false,
    head,
    body,
    foot,
    onDismiss = undefined,
}: NsAlertProps): ReactElement {
    const [alertType, setAlertType] = useState('banner');
    const windowSize = useWindowSize();

    const hasDismissListener = typeof onDismiss === 'function';

    useEffect(() => {
        if (!context) {
            console.error(`Invalid prop value for 'context': ${context}`);
        }
        if (!type) {
            console.error(`Invalid prop value for 'type': ${type}`);
        }
        if (type === 'auto') {
            setAlertType(windowSize.width < threshold ? 'card' : 'banner');
        } else {
            setAlertType(type);
        }
    }, [threshold, type, windowSize.width, context]);

    return (
        <AlertContainer visible={visible} data-testid="alert-container">
            <Alert type={alertType as AlertType} context={context as ContextType}>
                <AlertIcon>
                    <NsIcon
                        name={iconMap[context] || iconMap.default}
                        color={colorMap[context] || colorMap.default}
                        size="large"
                    />
                </AlertIcon>
                <AlertHead>
                    <Header
                        head={
                            <NsTypography variant="body-xl" className="alert-head-title" weight="bold" noSpacing>
                                {title}
                            </NsTypography>
                        }
                    >
                        {head}
                    </Header>
                </AlertHead>
                {hasDismissListener && (
                    <AlertCloseButton data-testid="alert-close-button" onClick={onDismiss}>
                        <NsIcon name="close" size="small" cursor="pointer" />
                    </AlertCloseButton>
                )}
                <AlertContent type={alertType as AlertType}>
                    <AlertBody>{body}</AlertBody>
                    {foot ? <AlertFoot type={alertType as AlertType}>{foot}</AlertFoot> : null}
                </AlertContent>
            </Alert>
        </AlertContainer>
    );
}
