import React, { ReactElement } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { ShoppingCart } from '@mui/icons-material';
import { nuskinTheme } from '@nuskin/foundation-theme';
import { expect } from '@storybook/jest';
import type {
    Meta,
    StoryObj,
} from '@storybook/react';
import { within } from '@storybook/testing-library';

import { NsButton } from './';

const { palette } = nuskinTheme;

type ComponentType = typeof NsButton;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsButton',
    component: NsButton,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
            name: 'Children/Content',
            defaultValue: 'Button',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        iconOnly: { control: 'hide' },
    },
    args: {
        children: 'Button',
        color: 'primary',
        size: 'medium',
        disabled: false,
        variant: 'contained',
        fullWidth: false,
        startIcon: '',
        endIcon: '',
    },
} as MetaStory;

export const button: Story = {
    args: {},
};

export const IconOnlyButton: Story = {
    render: (args: any):ReactElement => (
        <NsButton {...args} iconOnly darkModeEnabled={false}>
            <ShoppingCart />
        </NsButton>
    ),

    argTypes: {
        children: {
            control: 'hide',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'hide' },
        size: { control: 'hide' },
        iconOnly: { control: 'hide' },
    },
};
export const ButtonWithIcon: Story = {
    render: (args: any):ReactElement => (
        <NsButton {...args} darkModeEnabled={false} startIcon={<ShoppingCart />}>
            Add to Cart
        </NsButton>
    ),
    argTypes: {
        children: {
            control: 'hide',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        iconOnly: { control: 'hide' },
    },
};

export const TextVariant: Story = {
    args: {
        color: 'success',
        variant: 'text',
        size: 'large',
        children: 'click me! icon',
    },
    play: ({ canvasElement }) => {
        const canvas = within(canvasElement);
        const button = canvas.getByText('click me! icon');
        expect(button).toBeInTheDocument();
        expect(button).toHaveStyle(`color: ${palette.success.main}`);
        expect(button).toHaveStyle('background-color: rgba(0, 0, 0, 0);');
    },
};

export const IconOnly: Story = {
    args: {
        iconOnly: true,
        color: 'success',
        variant: 'text',
        size: 'large',
        children: 'click me! icon',
    },
    play: ({ canvasElement }) => {
        const canvas = within(canvasElement);
        const button = canvas.getByText('click me! icon');
        expect(button).toBeInTheDocument();
        expect(button).toHaveStyle(`color: ${palette.success.main}`);
        expect(button).toHaveStyle('background-color: rgba(0, 0, 0, 0);');
    },
};
