import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsTypography } from '../';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsAwardCardProps = {
    title: string;
    awardName: string;
    mediaOutlet: string;
    backgroundImageDetail: BynderImageDataType;
    className?: string;
    fontColor?: 'primary' | 'secondary';
};

const CardContainer = styled(Box)`
    display: flex;
    flex-direction: column;
    position: relative;
    align-items: center;
    width: 160px;
    height: auto;
    .image {
        width: 160px;
        height: auto;
        object-fit: cover;
    }
    .content {
        display: flex;
        flex-direction: column;
        text-align: center;
        align-items: center;
        margin-top: 25px;
    }
    .content-text: {
        margin-top: 20px;
    }
    .action-link {
        margin-top: 10px;
        align-self: start;
    },
`;

export default function NsAwardCard({
    title,
    awardName,
    mediaOutlet,
    backgroundImageDetail,
    className,
    fontColor,
}: NsAwardCardProps): ReactElement {
    return (
        <CardContainer className={className} role="award-card" component="div" data-testid="award-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <NsTypography weight="normal" className="title" variant="h5" color={fontColor}>
                    {title}
                </NsTypography>
                <NsTypography className="content-text" variant="body-l" color={fontColor}>
                    {awardName}
                </NsTypography>
                <NsTypography className="content-text" variant="body-l" color={fontColor}>
                    {mediaOutlet}
                </NsTypography>
            </div>
        </CardContainer>
    );
}
