import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsLargeCardProps = {
    title: string;
    subtitle?: string;
    intro: string;
    backgroundImageDetail: BynderImageDataType;
    isHorizontal?: boolean;
    button?: NsCardButton;
    className?: string;
    fontColor?: 'primary' | 'secondary';
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ isHorizontal, matches }) => {
    let width = '450px',
        paddingLeft = '0px',
        justifyContent,
        fontSizeSub = '16px',
        fontSizeTitle = '26px',
        imageWidth = '100%';

    if (isHorizontal) {
        width = '600px';
        paddingLeft = '30px';
        justifyContent = 'center';
        fontSizeSub = '16px';
        fontSizeTitle = '26px';
        imageWidth = '50%';
    }
    let direction = isHorizontal ? ('row' as 'row') : ('column' as 'column');

    return {
        display: 'flex',
        flexDirection: direction,
        position: 'relative',
        width,
        '.bg-image': {
            objectFit: 'cover',
            height: '220px',
            width: imageWidth,
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            paddingLeft,
            justifyContent,
        },
        '.subtitle': {
            fontSize: fontSizeSub,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: fontSizeTitle,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.primary': {
            color: '#fff',
        },
        '.secondary': {
            color: '#000',
        },
        '.cta': {
            marginTop: '10px',
        },
        '@media (max-width: 768px)': {
            width: '100%',
        },
    };
});

export default function NsLargeCard({
    title,
    subtitle,
    backgroundImageDetail,
    intro,
    isHorizontal,
    button,
    className,
    fontColor,
}: NsLargeCardProps): ReactElement {
    return (
        <CardContainer
            className={className}
            role="large-card"
            component="div"
            data-testid="large-card"
            isHorizontal={isHorizontal}
        >
            <BynderMedia className="bg-image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <article className={`subtitle ${fontColor}`}>{subtitle}</article>
                <article className={`title ${fontColor}`}>{title}</article>
                <article className={`subtitle ${fontColor}`}>{intro}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
