import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsTypography } from '../';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
    fluid?: boolean;
    showArrowWithButtonText?: boolean;
    fontColor?: 'primary' | 'secondary';
};
const textVariantButton = {
    padding: '0 0 4px',
    gap: '7px',
    span: {
        margin: 0,
    },
    '> div': {
        margin: 0,
    },
    '.MuiButton-endIcon': {
        svg: {
            g: {
                strokeWidth: 2,
            },
        },
    },
};
const buttonVariantStyle = (variant: string) => (variant === 'text' ? { a: textVariantButton } : {});
const CardContainer = styled(Box)<{ fluid: boolean; variant: string }>(({ fluid, variant }) => {
    const textVariantCssModification = buttonVariantStyle(variant);

    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: fluid ? '100%' : '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: fluid ? '100%' : '300px',
            flexDirection: 'column',
            flexGrow: 1,
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.primary': {
            color: '#fff',
        },
        '.secondary': {
            color: '#000',
        },
        '.cta': {
            marginTop: 'auto',
            ...textVariantCssModification,
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageDetail,
    button,
    className,
    fluid,
    showArrowWithButtonText = false,
    fontColor,
}: NsMediumCardProps): ReactElement {
    return (
        <CardContainer
            className={className}
            role="medium-card"
            component="div"
            data-testid="medium-card"
            fluid={fluid || false}
            variant={button?.buttonVariant ?? ''}
        >
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <NsTypography variant="h5" color={fontColor} className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className={`subtitle mt-3 mb-5 ${fontColor}`}>{subtitle}</article>
                {button ? <CardButton {...button} showArrowWithText={showArrowWithButtonText} /> : null}
            </div>
        </CardContainer>
    );
}
