import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageDetail: BynderImageDataType;
    className?: string;
    fontColor?: 'primary' | 'secondary';
};

const CardContainer = styled(Box)`
    background-clip: border-box;
    display: flex;
    flex-direction: column;
    word-wrap: break-word;
    position: relative;
    overflow: hidden;
    max-width: 165px;
    height: 272px;
    background-color: #fff;
    .image {
        height: 180px;
        overflow: hidden;
        object-fit: contain;
    }
    .content {
        padding: 20px;
        display: flex;
        flex-direction: column;
        min-height: 92px;
        max-height: 92px;
        justify-content: space-around;
    }
    .body-title {
        font-size: 18px;
        font-weight: 600;
        display: -webkit-box;
        -webkit-box-orient: vertical;
        -webkit-line-clamp: 1;
        overflow: hidden;
        text-overflow: ellipsis;
        margin: 0;
    }
    .body-text {
        font-size: 12px;
        font-weight: 700;
        display: -webkit-box;
        -webkit-box-orient: vertical;
        -webkit-line-clamp: 1;
        overflow: hidden;
        text-overflow: ellipsis;
        color: #8c8c8c;
        margin: 0;
    }
`;

const NsPost = ({ text, body, backgroundImageDetail, className, fontColor }: NsPostProps): ReactElement => {
    return (
        <CardContainer className={className} data-testid="post-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <article className="content">
                <h2 className={`body-title ${fontColor}`} title={text}>
                    {text}
                </h2>
                <p className={`body-text ${fontColor}`} title={body?.substring(0, 80)}>
                    {body}
                </p>
            </article>
        </CardContainer>
    );
};
export default NsPost;
