import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsXLargeCardProps = {
    title: string;
    subtitle: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
    fontColor?: 'primary' | 'secondary';
};

const CardContainer = styled(Box)`
    background-color: #fff;
    display: flex;
    height: 620px;
    width: 450px;
    position: relative;
    .image {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }
    .gradientOverlay {
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background: linear-gradient(to top, rgba(0, 0, 0, 0.6) 0%, transparent 50%);
    }
    .content {
        position: absolute;
        height: 100%;
        width: 100%;
        padding: 40px 40px 25px 30px;
        display: flex;
        flex-direction: column;
    }
    .subtitle {
        color: #fff;
        font-size: 11px;
        font-weight: 400;
        margin-top: auto;
    }
    .title {
        color: #fff;
        font-size: 26px;
        font-weight: 400;
        margin-top: 20px;
    }
    .primary {
        color: #fff;
    }
    .secondary {
        color: #000;
    }
    .cta {
        margin-top: 20px;
    }
`;

export default function NsXLargeCard({
    title,
    subtitle,
    backgroundImageDetail,
    button,
    className,
    fontColor,
}: NsXLargeCardProps): ReactElement {
    return (
        <CardContainer className={className} role="x-large-card" component="div" data-testid="x-large-card">
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="gradientOverlay"></div>
            <div className="content">
                <article className={`subtitle ${fontColor}`}>{subtitle}</article>
                <article className={`title ${fontColor}`}>{title}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
