import { render, screen } from '@testing-library/react';
import { NsLargeCard } from '../';
import { ImageData1 } from '../fixtures/ImageData1';

describe('NsLargeCard component', () => {
    const props = {
        isHorizontal: false,
        title: 'Personal Care',
        subtitle: 'Subtitle',
        intro: 'Nu Skin® product lines combine nature and science for skincare benefits you can see and feel.',
        button: {
            showButton: true,
            buttonText: 'REVEAL YOUR BEST SKIN',
            buttonVariant: 'outlined' as 'outlined',
            buttonColor: 'secondary' as 'secondary',
            url: 'https://www.forceforgood.org/',
        },
        backgroundImageDetail: ImageData1,
    };

    it('1. renders with correct content and styles', () => {
        render(<NsLargeCard {...props} />);

        const button = screen.queryByText('REVEAL YOUR BEST SKIN');

        expect(screen.getByText(props.title)).toBeInTheDocument();
        expect(screen.getByText(props.subtitle)).toBeInTheDocument();
        expect(screen.getByText(props.intro)).toBeInTheDocument();
        expect(screen.getByText(props.intro)).toBeInTheDocument();
        expect(button).toBeInTheDocument();
    });

    it('2. renders with flexDirection=row when isHorizontal is true', () => {
        const { getByTestId } = render(<NsLargeCard {...{ ...props, isHorizontal: true }} />);

        expect(getByTestId('large-card')).toHaveStyle('flex-direction: row');
    });

    it('3. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        const { container } = render(<NsLargeCard {...updatedProps} />);

        const button = container.querySelector('.cta');
        expect(button).toBeNull();
    });
});
