import React, { ReactElement, useMemo } from 'react';

import Slider from 'react-slick';

import { styled } from '@nuskin/foundation-theme';

import { NsScrollingCarousalProps } from '../';

type StyledType = {
    dotsBottomPixel?: number;
};

const StyledDiv = styled('div')<StyledType>(({ dotsBottomPixel }) => {
    return {
        '.slick-dots': {
            zIndex: 9,
            bottom: `${dotsBottomPixel ?? -25}px`,
            opacity: '0.5',
        },
    };
});

const NsScrollingCarousal = ({
    slides,
    scrollSeconds,
    stillSeconds,
    renderSlide,
    settings,
    dotsBottomPixel,
    additionalProps,
}: NsScrollingCarousalProps): ReactElement => {
    const defaultSettings = useMemo(() => {
        return {
            ...settings,
            autoplay: true,
            autoplaySpeed: stillSeconds * 1000 || 2000, // autoplaySpeed = delay between scroll in milliseconds
            accessibility: true,
            adaptiveHeight: true,
            arrows: true,
            draggable: true,
            dots: false,
            infinite: true,
            speed: scrollSeconds * 1000 || 500, // speed = animation speed in milliseconds
            slidesToShow: 1,
            slidesToScroll: 1,
            swipeToSlide: true,
        };
    }, [stillSeconds, scrollSeconds, settings]);
    return (
        <StyledDiv
            className="scrolling-carousal-wrapper"
            dotsBottomPixel={dotsBottomPixel}
            data-testid={additionalProps?.testid ?? 'scrolling-carousal-test-id'}
        >
            <Slider {...defaultSettings}>{slides.map(renderSlide)}</Slider>
        </StyledDiv>
    );
};

export default NsScrollingCarousal;
