import { ReactElement } from 'react';

import { NsColumnControl } from '@/common/index';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import type { Meta, StoryObj } from '@storybook/react';

import { childrenMapping, selectDivOptions } from './common';
import { DivArray } from './DivArray';

type ComponentType = typeof NsColumnControl;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Data Display/Column/NsColumnControl',
    component: NsColumnControl,
    decorators: [withCenterDecorator],
    argTypes: {
        columnClass: {
            control: 'text',
            defaultValue: 'ns-col-lg-1-1-1 ns-col-md-1-1 ns-col-sm-1',
        },
        children: {
            control: {
                type: 'select',
                options: selectDivOptions,
            },
            defaultValue: (<DivArray elementsCount={8} />) as ReactElement,
            mapping: childrenMapping,
        },
    },
    args: {
        columnClass: 'ns-col-lg-1-1-1 ns-col-md-1-1 ns-col-sm-1',
        children: (<DivArray elementsCount={12} />) as ReactElement,
    },
} as MetaStory;

export const ResponsiveColumnControl: Story = {};
export const SingleColumnControl: Story = {
    args: { columnClass: '' },
};
export const TwoColumn11: Story = {
    args: { columnClass: 'ns-col-lg-1-1' },
};
export const TwoColumn21: Story = {
    args: { columnClass: 'ns-col-lg-2-1' },
};
export const ThreeColumn111: Story = {
    args: { columnClass: 'ns-col-lg-1-1-1' },
};
export const ThreeColumn211: Story = {
    args: { columnClass: 'ns-col-lg-2-1-1' },
};
export const ThreeColumn121: Story = {
    args: { columnClass: 'ns-col-lg-1-2-1' },
};
export const ThreeColumn11Responsive: Story = {
    args: { columnClass: 'ns-col-lg-1-1 ns-col-md-1' },
};
export const FourColumn1111: Story = {
    args: { columnClass: 'ns-col-lg-1-1-1-1' },
};
export const FourColumn1111Responsive: Story = {
    args: { columnClass: 'ns-col-lg-1-1-1-1 ns-col-md-1-1 ns-col-sm-1' },
};
