import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { Themed } from '../common.types';
const { color, paletteColor, isDarkMode } = ColorUtils;

export const DropdownContainer = styled.div<{ disabled: boolean }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
    cursor: ${({ disabled }) => (disabled ? 'not-allowed' : 'pointer')};
`;

/** this function also used for SelectHead */
export const getDropdownHeadBorder = ({ type, theme }: { type: string } & Themed) => {
    if (type === 'outlined') {
        const borderColor = color('primary', 'black')({ theme });
        return `1px solid ${borderColor}`;
    }
    return 'none';
};
export const DropdownHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${getDropdownHeadBorder};
    color: ${paletteColor('primary')};
`;

export const DropdownButton = styled.div`
    padding-right: 10px;
    -webkit-user-select: none;
    -ms-user-select: none;
    user-select: none;
`;

export const DropdownList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 999;
    border: 1px solid ${({ borderColor, theme }) => paletteColor(borderColor)({ theme })};
    margin-top: 10px;
    width: 100%;
    color: ${paletteColor('primary', 'main')};
    background-color: ${paletteColor('primary', 'contrastText')};
`;

const getListBgColor = (theme: FoundationTheme.Theme) => {
    return color('accentColorB', isDarkMode({ theme }) ? '50' : '10')({ theme });
};

export const DropdownOptionContainer = styled.div`
    cursor: pointer;
    &:last-child {
        border-bottom: none;
    }
`;

export const ListItem = styled.div`
    &:hover {
        background-color: ${({ theme }) => getListBgColor(theme)};
    }
    &:active {
        background-color: #7de3e8;
    }
    padding: 10px;
`;
