import { userEvent } from '@storybook/testing-library';
import { render, screen } from '@testing-library/react';
import React from 'react';

import { emailPattern } from '../validations/regex';
import NsEmailSimple from './NsEmailSimple';
import { NsEmailSimpleProps } from './types';

const getInput = (propsData: NsEmailSimpleProps) => {
    const { container } = render(<NsEmailSimple {...propsData} />);
    const inputElement = container.querySelector('input');
    return inputElement;
};
// TODO: fix this spec
describe('NsEmailSimple', () => {
    let mockCheckEmail = jest.fn().mockResolvedValue([true, false]); // isValid, isAvailable
    let propsData = {
        disabled: false,
        label: 'Email',
        required: true,
        maxLength: 50,
        invalidEmailMessage: 'Please enter a valid email',
        dupedEmailMessage: 'Email ID already exists',
        requiredErrorMessage: 'Email field is required',
        checkEmail: mockCheckEmail,
    };
    it('1. renders email field', async () => {
        const { container } = render(<NsEmailSimple {...propsData} />);
        const inputElement = container.querySelector('input');
        expect(inputElement).toBeInTheDocument();
        if (inputElement) {
            const inputValue = 'test';
            await userEvent.type(inputElement, inputValue);
            await userEvent.tab();
            expect(inputElement).toHaveValue(inputValue);
            await userEvent.clear(inputElement);
            expect(inputElement).toHaveValue('');

            const inputValue2 = 'test@gmail.com';
            await userEvent.type(inputElement, inputValue2);
            await userEvent.tab();
            expect(inputElement).toHaveValue(inputValue2);
        }
    });

    it('2. renders email field with invalid regex error', async () => {
        const inputElement = getInput(propsData);
        if (!inputElement) {
            return;
        }
        const mockCheckEmail = jest.fn().mockResolvedValue([true, true]); // isValid, isAvailable
        render(<NsEmailSimple {...propsData} checkEmail={mockCheckEmail} />);
        const wrongInputValue = 'test1!gmail.com';
        await userEvent.clear(inputElement);
        await userEvent.type(inputElement, wrongInputValue);
        await userEvent.tab();
        expect(inputElement).toHaveValue(wrongInputValue);
    });
    it('3. check email', async () => {
        const inputElement = getInput(propsData);
        if (!inputElement) {
            return;
        }
        const mockCheckEmail2 = jest.fn().mockResolvedValue([true, false]); // isValid, isAvailable
        render(<NsEmailSimple {...propsData} checkEmail={mockCheckEmail2} />);
        await userEvent.clear(inputElement);
        await userEvent.type(inputElement, 'test@gmail.co');
        userEvent.tab();
        expect(inputElement).toHaveValue('test@gmail.co');
    });
    it('4. renders email field with invalid error', async () => {
        let mockCheckEmail = jest.fn().mockResolvedValue([false, false]); // isValid, isAvailable
        let props = {
            ...propsData,
            checkEmail: mockCheckEmail,
        };
        render(<NsEmailSimple {...props} />);
        const emailField = (await screen.findByTestId('email-field-test')) as HTMLInputElement;
        expect(emailField).toBeInTheDocument;
        const inputElement = emailField.querySelector('input');
        if (!inputElement) {
            return;
        }
        await userEvent.type(inputElement, 'test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
    it('5. renders email field without error', async () => {
        const mock = jest.fn().mockResolvedValue([true, true]);
        const props = {
            ...propsData,
            checkEmail: mock,
        };
        const inputElement = getInput(props);
        if (!inputElement) {
            return;
        }
        await userEvent.type(inputElement, 'test@gmail.com');
        expect(inputElement).toHaveValue('test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
    it('6. renders email field with API error', async () => {
        let mock = jest.fn().mockResolvedValue(undefined);
        let props = {
            ...propsData,
            checkEmail: mock,
        };
        const inputElement = getInput(props);
        if (!inputElement) {
            return;
        }
        await userEvent.type(inputElement, 'test@gmail.com');
        expect(inputElement).toHaveValue('test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
});
