import { ReactElement } from 'react';

import { useTheme } from '@mui/material';
import { ColorUtils } from '@nuskin/foundation-theme';

import { IconWrapper } from './NsIcon.styled';
import IconVariants from './NsIconVariants';
import { NsIconNameType, NsIconProps } from './types.d';

const { paletteColor } = ColorUtils;

const NsIcon = ({
    name,
    size,
    color = 'primary',
    testId = 'icon',
    className,
    colorOverride,
    onClick = () => {},
    cursor = 'pointer',
    ...rest
}: NsIconProps): ReactElement | null => {
    const Icon = IconVariants[name as NsIconNameType];
    const theme = useTheme();
    const iconColor = paletteColor(color)({ theme });
    if (!Icon) {
        return null;
    }

    return (
        <IconWrapper
            {...rest}
            data-testid={testId}
            size={size || 'large'}
            className={className}
            onClick={onClick}
            cursor={cursor}
        >
            <Icon color={colorOverride ? colorOverride : (iconColor as any)} />
        </IconWrapper>
    );
};

export default NsIcon;
