import { ReactElement } from 'react';

import { CslpTag } from '../common.types';
/* eslint-disable @next/next/no-img-element */
import { getImageType, getMediaUrl, getUrlBasedOnDerivative } from './bynder-util';
import { BynderImageDataType } from './types';

type BynderMediaProps = {
    imageDetail: BynderImageDataType;
    suffix?: string;
    className?: string;
    testId?: string;
    liveTag?: CslpTag;
};
export const BynderMedia = ({ imageDetail, suffix, className, testId, liveTag }: BynderMediaProps): ReactElement => {
    const { files, name, selected, previewUrls, isPublic } = imageDetail;
    const { url = '', fit, position, altText = '', bgColor, type } = selected ?? {};
    const imageDerivativeType = getImageType(url, name, files);
    const mediaUrl = getMediaUrl(selected, isPublic, previewUrls);
    let transformedMediaUrl = getUrlBasedOnDerivative(mediaUrl, imageDerivativeType, suffix ?? '');
    if (type === 'VIDEO') {
        return (
            <div {...liveTag}>
                <video
                    loop
                    autoPlay
                    muted
                    width="100%"
                    style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
                    className={`${className || ''} bynder-image`}
                    data-testid={testId || 'test-bynder-video'}
                >
                    <source src={transformedMediaUrl} type="video/mp4" />
                    <source src={transformedMediaUrl} type="video/ogg" />
                </video>
            </div>
        );
    }
    return (
        <img
            {...liveTag}
            data-testid={testId || 'test-bynder-image'}
            className={`${className || ''} bynder-image`}
            src={transformedMediaUrl}
            alt={altText}
            style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
        />
    );
};
