import type { Meta, StoryObj } from '@storybook/react';
import { NsInputField } from '.';
import { NsIcon } from '../icon';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsInputField;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsInputField',
    component: NsInputField,
    decorators: [withCenterDecorator],
    args: {
        helperText: '',
        iconSide: <NsIcon name="trash" />,
        focused: false,
        placeholder: 'enter text',
        disabled: false,
        fullWidth: false,
    },
    argTypes: {
        fieldState: { control: 'select', options: ['default', 'success', 'error'] },
        value: { control: 'text' },
        helperText: { control: 'text', description: 'text shown below input' },
        required: { control: 'boolean' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        showOptional: { control: 'boolean', description: 'if true, an optional text is shown along with label' },
        focused: { control: 'boolean' },
    },
} as MetaStory;

export const Default: Story = {
    args: {
        value: 'Input value',
        fieldState: 'success',
    },
};

export const WithLabel: Story = {
    args: {
        ...Default.args,
        label: 'Input Label',
    },
};

export const WithOptionalLabel: Story = {
    args: {
        ...WithLabel.args,
        showOptional: true,
        required: false,
    },
};

export const WithHelperText: Story = {
    args: {
        ...WithOptionalLabel.args,
        helperText: 'Please enter input value',
    },
};
