import React from 'react';
import { render } from '@/test-utils/index';
import NsLink from './NsLink';

describe('NsLink Component', () => {
    test('renders a basic link with default props', () => {
        const { getByText } = render(<NsLink href="https://example.com">Example Link</NsLink>);
        const linkElement = getByText('Example Link');
        expect(linkElement.tagName).toBe('A');
        expect(linkElement).toHaveAttribute('href', 'https://example.com');
        expect(linkElement).toHaveStyle('text-decoration: underline');
    });

    test('renders a link with underline on hover', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" underlineOnHover>
                Hover Link
            </NsLink>
        );
        const linkElement = getByText('Hover Link');
        expect(linkElement).toHaveStyle('text-decoration: underline');
    });

    test('renders a disabled link', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" disabled>
                Disabled Link
            </NsLink>
        );
        const linkElement = getByText('Disabled Link');
        expect(linkElement).toHaveStyle('cursor: default');
        expect(linkElement).toHaveStyle('opacity: 0.6');
        // expect(linkElement).toHaveAttribute('aria-disabled', 'true');
    });

    test('renders a link with SSR (StyledNextLink)', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" isSsr>
                SSR Link
            </NsLink>
        );
        const linkElement = getByText('SSR Link');
        // expect(linkElement.tagName).toBe('a');
        expect(linkElement.closest('a')).toHaveAttribute('href', 'https://example.com');
    });

    test('renders a link with the "contained" variant', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" variants="contained">
                Contained Link
            </NsLink>
        );
        const linkElement = getByText('Contained Link');
        // expect(linkElement.tagName).toBe('a');
        expect(linkElement.closest('a')).toHaveAttribute('href', 'https://example.com');
        expect(linkElement).toHaveClass('cta-text');
    });

    test('renders a link with the "secondary" variant', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" variants="secondary">
                Secondary Link
            </NsLink>
        );
        const linkElement = getByText('Secondary Link');
        expect(linkElement).toHaveStyle('color: secondary');
    });

    test('renders children correctly', () => {
        const { getByText } = render(
            <NsLink href="https://example.com">
                <span>Custom Child</span>
            </NsLink>
        );
        const childElement = getByText('Custom Child');
        expect(childElement).toBeInTheDocument();
    });

    test('passes additional props to the link', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" additionalProps={{ 'data-testid': 'custom-link' }}>
                Custom Link
            </NsLink>
        );
        const linkElement = getByText('Custom Link');
        expect(linkElement).toHaveAttribute('data-testid', 'custom-link');
    });

    test('renders SecondaryWrapper for "contained" variant', () => {
        const { getByText } = render(
            <NsLink href="https://example.com" variants="contained">
                Contained Link
            </NsLink>
        );
        const linkElement = getByText('Contained Link');
        expect(linkElement.closest('a')).toHaveAttribute('href', 'https://example.com');
    });
});