import { styled } from '@nuskin/foundation-theme';
import MUILink from '@mui/material/Link';
import NextLink from 'next/link';

type StyledProps = {
    disabled?: boolean;
    $underlineOnHover?: boolean;
    variants?: string;
    outlined?: boolean;
    showHorizontal?: boolean;
};

/**
 * Wrapper StyledMUILink / StyledNextLink for NsLink.tsx
 * @params ( theme: { palette }) / Provide the color's to container from @nuskin/foundation-theme
 * @params ( disabled: boolean) / Element will be disable only when disabled is true
 */

export const linkDefaultStyles = `
    -webkit-tap-highlight-color: transparent;
    background-color: transparent;
    background-repeat: no-repeat;
    border: none;
    cursor: pointer;
    outline: none;
    padding: 0;
    text-decoration: none;
    transition: transform 120ms linear;
    color: inherit;
    &:focus {
        outline: none;
        text-decoration: underline;
    }
`;

const getLinkStyles = ({ disabled, $underlineOnHover = true }: StyledProps) => {
    if (disabled) {
        return `
            cursor: default;
            pointer-events: all;
            opacity: 0.6;
        `;
    } else if ($underlineOnHover) {
        return `&:hover {
                text-decoration: underline;
                text-underline-offset: 4px;
                text-decoration-color: currentcolor;
            }`;
    }
    return '';
};

const getVariantStyles = ({ variants, outlined, showHorizontal }: StyledProps) => {
    const styles: Record<string, string> = {
        primary: `
            border-radius: 4px; 
            padding: 8px 16px; 
            background-color: ${outlined ? '#transparent' : 'black'}; 
            color: ${outlined ? 'black' : 'white'}; 
            border: ${outlined ? '1px solid black' : 'none'}; 
            text-align: center; 
            cursor: pointer; 
            text-decoration: none;
            display: inline-block; 
            &:hover {
                background-color: '#8C8C8C';  
            }
            @media (max-width: 1024px) {
               margin: auto;
            }
            @media (max-width: 1023px) {
               margin: ${showHorizontal?'0':'0 auto'};
               width: fit-content; 
            }
            
        `,
        secondary: `
            text-align: center;
            cursor: pointer;
            text-decoration: none;
            display: inline-block;
        `,
    };

    return variants ? styles[variants] || '' : '';
}

export const StyledNextLink = styled(NextLink)<StyledProps>`
    ${linkDefaultStyles};
    ${getLinkStyles}
    ${getVariantStyles}
`;

export const StyledLink = styled(MUILink)<StyledProps>`
    ${linkDefaultStyles};
    ${getLinkStyles}
    ${getVariantStyles}
`;
