import { ReactElement } from 'react';

import { NavTabs, NsLink, NsTypography } from '../';
import { Show } from '../utility';
import { NavTabBox, NavTabUnderLine, NavTitlesBox } from './NsNavTab.styled';

type NavTitlesProps = {
    tabs: NavTabs[];
    setActive(_x: string): void;
    active: string | null;
    tabTitleClassName?: string;
};

export const NavTitles = ({ tabs, setActive, active, tabTitleClassName }: NavTitlesProps): ReactElement => {
    const NavTitleTypography = (tab: NavTabs) => (
        <NsTypography
            variant={tab.textVariant}
            additionalProps={{ ...tab?.liveTag }}
            className={`${tabTitleClassName} ${!active ? 'opacity-8' : ''}`}
            color={tab.tabName === active ? tab.activeColor : tab.color}
            noSpacing
        >
            {tab.tabName}
        </NsTypography>
    );

    return (
        <NavTitlesBox className="desktop-nav-titles">
            {tabs?.map((tab) => {
                const handleMouseEnter = () => {
                    setActive(tab.tabName);
                };
                return (
                    <div
                        key={tab?.tabName}
                        data-testid={tab?.tabName}
                        className="relative cursor-pointer"
                        onMouseEnter={handleMouseEnter}
                    >
                        <NavTabBox
                            className="nav-tab-box"
                            data-testid={tab.tabName + '-list'}
                            transition={{
                                duration: 0.3,
                            }}
                            animate
                        >
                            {tab?.tabLink ? (
                                <NavTitleTypography {...tab}>
                                    <NsLink href={tab.tabLink} underlineOnHover={false} />
                                </NavTitleTypography>
                            ) : (
                                <NavTitleTypography {...tab} />
                            )}
                        </NavTabBox>
                        <Show when={active === tab.tabName}>
                            <NavTabUnderLine data-testid="underline" layoutId="underline" color={tab.activeColor} />
                        </Show>
                    </div>
                );
            })}
        </NavTitlesBox>
    );
};
