import { fireEvent } from '@testing-library/react';
import { NsNavTabComponent } from './NsNavTab';
import { NavTabs } from './types';
import { render } from '@/test-utils/index';

const tabs: NavTabs[] = [
    {
        tabName: 'Skin & Beauty',
        tabContent: <>Skin & Beauty</>,
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'Beauty Devices',
        tabContent: <>Beauty Devices</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'Product Lines',
        tabContent: <>Product Lines</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
    {
        tabName: 'New & Loved',
        tabContent: <>New & Loved</>,
        color: 'primary',
        activeColor: 'success',
        textVariant: 'h5',
    },
];

describe('Nav Bar Component', () => {
    it('1. should render Nav Bar Component with variant', () => {
        const { container } = render(
            <NsNavTabComponent tabTitleClassName="text-center" className="mb-2" tabs={tabs} />
        );
        const li = container.querySelectorAll('li');
        expect(li.length).toBe(4);
        li.forEach((list, i) => expect(list).toHaveTextContent(tabs[i].tabName));
        expect(container).toBeInTheDocument();
    });

    it('2. should open and close the drawer', () => {
        const { container, getByTestId } = render(<NsNavTabComponent showDrawer className="mb-2" tabs={tabs} />);
        const li = container.querySelectorAll('li');
        expect(li.length).toBe(4);
        li.forEach((list, i) => expect(list).toHaveTextContent(tabs[i].tabName));
        expect(container).toBeInTheDocument();
        fireEvent.mouseOver(getByTestId('Skin & Beauty'));
        expect(getByTestId('nav-drawer')).toBeInTheDocument();
        fireEvent.mouseLeave(getByTestId('Skin & Beauty'));
        expect(getByTestId('nav-drawer-container').firstChild).not.toBeInTheDocument();
    });

    it('3. should show the underline on hover', () => {
        const { getByTestId } = render(<NsNavTabComponent showDrawer={false} className="mb-2" tabs={tabs} />);
        fireEvent.mouseOver(getByTestId('Skin & Beauty'));
        expect(getByTestId('underline')).toBeInTheDocument();
    });
});
