import type { PropsWithChildren, ReactElement } from 'react';

import { MaterialDesignContent, SnackbarProvider, SnackbarProviderProps } from 'notistack';

import { ColorUtils, ScreenSize, styled } from '@nuskin/foundation-theme';

const { getGenomeColor } = ColorUtils;

const ToastNotification = styled(MaterialDesignContent)`
    width: 610px;
    height: 46px;
    box-shadow: none;
    padding: 0 20px;

    .toast-message-wrapper {
        width: 440px;
        text-overflow: ellipsis;
        overflow: hidden;
        white-space: nowrap;
    }

    @media (max-width: ${ScreenSize.md}px) {
        width: 343px;

        .toast-message-wrapper {
            width: 190px;
        }
    }

    #notistack-snackbar svg {
        font-size: 24px !important;
    }
    &.notistack-MuiContent-success {
        background-color: ${({ theme }) => getGenomeColor(theme, 'Success-10')};
        border: 1px solid ${({ theme }) => getGenomeColor(theme, 'Success-30')};
        color: ${({ theme }) => getGenomeColor(theme, 'Success-80')};

        svg g {
            stroke: ${({ theme }) => getGenomeColor(theme, 'Success-80')};
        }
    }
    &.notistack-MuiContent-error {
        background-color: ${({ theme }) => getGenomeColor(theme, 'Error-10')};
        border: 1px solid ${({ theme }) => getGenomeColor(theme, 'Error-50')};
        color: ${({ theme }) => getGenomeColor(theme, 'Error-60')};

        svg g {
            stroke: ${({ theme }) => getGenomeColor(theme, 'Error-60')};
        }
    }
    &.notistack-MuiContent-warning {
        background-color: ${({ theme }) => getGenomeColor(theme, 'Warning-10')};
        border: 1px solid ${({ theme }) => getGenomeColor(theme, 'Warning-40')};
        color: ${({ theme }) => getGenomeColor(theme, 'Warning-80')};

        svg g {
            stroke: ${({ theme }) => getGenomeColor(theme, 'Warning-80')};
        }
    }
    &.notistack-MuiContent-info {
        background-color: ${({ theme }) => getGenomeColor(theme, 'Info-10')};
        border: 1px solid ${({ theme }) => getGenomeColor(theme, 'Info-40')};
        color: ${({ theme }) => getGenomeColor(theme, 'Info-60')};

        svg g {
            stroke: ${({ theme }) => getGenomeColor(theme, 'Info-60')};
        }
    }
`;

const NsToastProvider = (props: PropsWithChildren<SnackbarProviderProps>): ReactElement => {
    const { children, autoHideDuration = 5000 } = props;
    return (
        <SnackbarProvider
            autoHideDuration={autoHideDuration}
            Components={{
                success: ToastNotification,
                error: ToastNotification,
                info: ToastNotification,
                warning: ToastNotification,
            }}
        >
            {children}
        </SnackbarProvider>
    );
};

export default NsToastProvider;
