import React, { ReactElement } from 'react';

import { VariantType } from 'notistack';

import type { Meta, StoryObj } from '@storybook/react';

import { NsToastProvider, ToastOptions, useToast } from '../';

type ComponentType = typeof NsToastProvider;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

type ToastProps = {
    variant?: VariantType;
    message?: string;
    options?: ToastOptions;
};

const ToastDecorator = (Story: React.FC): ReactElement => {
    return (
        <NsToastProvider>
            <Story />
        </NsToastProvider>
    );
};

const ToastComponent = (props: ToastProps): ReactElement => {
    const {
        variant,
        message = 'Toast Demo',
        options = {
            autoHideDuration: 2000,
        },
    } = props;
    const { showToast } = useToast();

    const toastHandler = () => {
        showToast(variant, message, options);
    };

    return (
        <div>
            <button onClick={toastHandler}>Show Toast</button>
        </div>
    );
};

export default {
    title: 'Components/Feedback/NsToast',
    component: ToastComponent,
    decorators: [ToastDecorator],
    argTypes: {
        variant: { control: 'select', options: ['success', 'error', 'warning', 'info'] },
        message: { control: 'text' },
        options: {
            autoHideDuration: { control: 'number' },
            persist: { control: 'boolean' },
            className: { control: 'text' },
            showCloseIcon: { control: 'boolean' },
            actions: {
                description: 'The buttons should  be passed to the Toast element',
            },
        },
    },
    args: {
        variant: 'error',
        message: 'Toast component',
        options: {
            autoHideDuration: 2000,
            persist: false,
            showCloseIcon: false,
            actions: [
                {
                    label: 'Undo',
                    onClick: () => alert('Undo clicked'),
                },
            ],
        },
    },
} as MetaStory;

export const NsToast: Story = {};
